==> ldap-account-manager_6.7.orig.tar.bz2: ldap-account-manager-6.7/templates/lib/extra/ckeditor/plugins/colorbutton/lang/sq.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'colorbutton', 'sq', {
	auto: 'Automatik',
	bgColorTitle: 'Ngjyra e Prapavijës',
	colors: {
		'000': 'E zezë',
		'800000': 'Ngjyrë gështenjë',
		'8B4513': 'Ngjyrë Shale Kafe',
		'2F4F4F': 'Ngjyrë Gri të errët ardëz',
		'008080': 'Ngjyrë bajukë',
		'000080': 'Ngjyrë Marine',
		'4B0082': 'Indigo',
		'696969': 'Gri e Errët',
		B22222: 'Tullë në Flakë',
		A52A2A: 'Ngjytë Kafe',
		DAA520: 'Shkop i Artë',
		'006400': 'E Gjelbër e Errët',
		'40E0D0': 'Ngjyrë e Bruztë',
		'0000CD': 'E Kaltër e Mesme',
		'800080': 'Vjollcë',
		'808080': 'Gri',
		F00: 'E Kuqe',
		FF8C00: 'E Portokalltë e Errët',
		FFD700: 'Ngjyrë Ari',
		'008000': 'E Gjelbërt',
		'0FF': 'Cyan',
		'00F': 'E Kaltër',
		EE82EE: 'Vjollcë',
		A9A9A9: 'Gri e Zbehtë',
		FFA07A: 'Salmon i Ndritur',
		FFA500: 'E Portokalltë',
		FFFF00: 'E Verdhë',
		'00FF00': 'Ngjyrë Gëlqere',
		AFEEEE: 'Ngjyrë e Bruztë e Zbehtë',
		ADD8E6: 'E Kaltër e Ndritur',
		DDA0DD: 'Ngjyrë Llokumi',
		D3D3D3: 'Gri e Ndritur',
		FFF0F5: 'Ngjyrë Purpur e Skuqur',
		FAEBD7: 'E Bardhë Antike',
		FFFFE0: 'E verdhë e Ndritur',
		F0FFF0: 'Ngjyrë Nektari',
		F0FFFF: 'Ngjyrë Qielli',
		F0F8FF: 'E Kaltër Alice',
		E6E6FA: 'Ngjyrë Purpur e Zbetë',
		FFF: 'E bardhë',
		'1ABC9C': 'Sian i Fortë',
		'2ECC71': 'Smerald',
		'3498DB': 'E kaltër e ndritur',
		'9B59B6': 'Ametist',
		'4E5F70': 'Kaltër në Gri',
		'F1C40F': 'E verdhë e gjallë',
		'16A085': 'Sian e errët',
		'27AE60': 'Smerald e errët',
		'2980B9': 'E kaltër e fortë',
		'8E44AD': 'Vjollcë e errët',
		'2C3E50': 'E kaltër e njomë',
		'F39C12': 'E Portokalltë',
		'E67E22': 'Ngjyrë karote',
		'E74C3C': 'E kuqe e zbehtë',
		'ECF0F1': 'Ngjyrë argjendi e ndritshme',
		'95A5A6': 'Sian në gri e lehtë',
		'DDD': 'Gri e lehtë',
		'D35400': 'Ngjyrë kungulli',
		'C0392B': 'E kuqe e fortë',
		'BDC3C7': 'Ngjyrë argjendi',
		'7F8C8D': 'Sian në gri',
		'999': 'Gri e Errët'
	},
	more: 'Më Shumë Ngjyra...',
	panelTitle: 'Ngjyrat',
	textColorTitle: 'Ngjyra e Tekstit'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/colorbutton/lang/sq.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'colorbutton', 'sq', {
	auto: 'Automatik',
	bgColorTitle: 'Ngjyra e Prapavijës',
	colors: {
		'000': 'E zezë',
		'800000': 'Ngjyrë gështenjë',
		'8B4513': 'Ngjyrë Shale Kafe',
		'2F4F4F': 'Ngjyrë Gri të errët ardëz',
		'008080': 'Ngjyrë bajukë',
		'000080': 'Ngjyrë Marine',
		'4B0082': 'Indigo',
		'696969': 'Gri e Errët',
		B22222: 'Tullë në Flakë',
		A52A2A: 'Ngjytë Kafe',
		DAA520: 'Shkop i Artë',
		'006400': 'E Gjelbër e Errët',
		'40E0D0': 'Ngjyrë e Bruztë',
		'0000CD': 'E Kaltër e Mesme',
		'800080': 'Vjollcë',
		'808080': 'Gri',
		F00: 'E Kuqe',
		FF8C00: 'E Portokalltë e Errët',
		FFD700: 'Ngjyrë Ari',
		'008000': 'E Gjelbërt',
		'0FF': 'Cyan',
		'00F': 'E Kaltër',
		EE82EE: 'Vjollcë',
		A9A9A9: 'Gri e Errët',
		FFA07A: 'Salmon i Ndritur',
		FFA500: 'E Portokalltë',
		FFFF00: 'E Verdhë',
		'00FF00': 'Ngjyrë Gëlqere',
		AFEEEE: 'Ngjyrë e Bruztë e Zbehtë',
		ADD8E6: 'E Kaltër e Ndritur',
		DDA0DD: 'Ngjyrë Llokumi',
		D3D3D3: 'Gri e Ndritur',
		FFF0F5: 'Ngjyrë Purpur e Skuqur',
		FAEBD7: 'E Bardhë Antike',
		FFFFE0: 'E verdhë e Ndritur',
		F0FFF0: 'Ngjyrë Nektari',
		F0FFFF: 'Ngjyrë Qielli',
		F0F8FF: 'E Kaltër Alice',
		E6E6FA: 'Ngjyrë Purpur e Zbetë',
		FFF: 'E bardhë',
		'1ABC9C': 'Sian i Fortë',
		'2ECC71': 'Smerald',
		'3498DB': 'E kaltër e ndritur',
		'9B59B6': 'Ametist',
		'4E5F70': 'Kaltër në Gri',
		'F1C40F': 'E verdhë e gjallë',
		'16A085': 'Sian e errët',
		'27AE60': 'Smerald e errët',
		'2980B9': 'E kaltër e fortë',
		'8E44AD': 'Vjollcë e errët',
		'2C3E50': 'E kaltër e njomë',
		'F39C12': 'E Portokalltë',
		'E67E22': 'Ngjyrë karote',
		'E74C3C': 'E kuqe e zbehtë',
		'ECF0F1': 'Ngjyrë argjendi e ndritshme',
		'95A5A6': 'Sian në gri e lehtë',
		'DDD': 'Gri e lehtë',
		'D35400': 'Ngjyrë kungulli',
		'C0392B': 'E kuqe e fortë',
		'BDC3C7': 'Ngjyrë argjendi',
		'7F8C8D': 'Sian në gri',
		'999': 'Gri e Errët'
	},
	more: 'Më Shumë Ngjyra...',
	panelTitle: 'Ngjyrat',
	textColorTitle: 'Ngjyra e Tekstit'
} );
